@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,10 +7,6 @@
 
 #include "sysman_standby_imp.h"
 
-#include "shared/source/helpers/debug_helpers.h"
-
-#include "level_zero/sysman/source/device/sysman_device_imp.h"
-
 namespace L0 {
 namespace Sysman {
 
