@@ -66,7 +66,7 @@ Program::Program(Context *context, bool isBuiltIn, const ClDeviceVector &clDevic
 std::string Program::getInternalOptions() const {
     auto pClDevice = clDevices[0];
     auto force32BitAddresses = pClDevice->getSharedDeviceInfo().force32BitAddresses;
-    auto internalOptions = getOclVersionCompilerInternalOption(pClDevice->getEnabledClVersion());
+    auto internalOptions = std::string(oclVersionCompilerInternalOption);
 
     if (force32BitAddresses && !isBuiltIn) {
         CompilerOptions::concatenateAppend(internalOptions, CompilerOptions::arch32bit);
@@ -123,7 +123,7 @@ Program::~Program() {
         cleanCurrentKernelInfo(i);
     }
 
-    for (const auto &buildInfo : buildInfos) {
+    for (auto &buildInfo : buildInfos) {
         freeGlobalBufferAllocation(buildInfo.constantSurface);
         freeGlobalBufferAllocation(buildInfo.globalSurface);
     }
@@ -135,7 +135,7 @@ Program::~Program() {
     }
 }
 
-void Program::freeGlobalBufferAllocation(const std::unique_ptr<NEO::SharedPoolAllocation> &globalBuffer) {
+void Program::freeGlobalBufferAllocation(std::unique_ptr<NEO::SharedPoolAllocation> &globalBuffer) {
     if (!globalBuffer) {
         return;
     }
@@ -161,6 +161,18 @@ void Program::freeGlobalBufferAllocation(const std::unique_ptr<NEO::SharedPoolAl
             DEBUG_BREAK_IF(!ret);
             return;
         }
+
+        if (auto &pool = device->getDevice().getConstantSurfacePoolAllocator();
+            pool.isPoolBuffer(graphicsAllocation)) {
+            pool.freeSharedAllocation(globalBuffer.release());
+            return;
+        }
+
+        if (auto &pool = device->getDevice().getGlobalSurfacePoolAllocator();
+            pool.isPoolBuffer(graphicsAllocation)) {
+            pool.freeSharedAllocation(globalBuffer.release());
+            return;
+        }
     }
 
     if ((nullptr != context) && (nullptr != context->getSVMAllocsManager()) && (context->getSVMAllocsManager()->getSVMAlloc(reinterpret_cast<const void *>(globalBuffer->getGpuAddress())))) {
