@@ -42,7 +42,7 @@
 #include "shared/source/utilities/tag_allocator.h"
 #include "shared/source/utilities/wait_util.h"
 
-#include "aub_services.h"
+#include "aubstream/hardware_context.h"
 
 #include <array>
 #include <iostream>
@@ -97,7 +97,6 @@ CommandStreamReceiver::CommandStreamReceiver(ExecutionEnvironment &executionEnvi
     auto &compilerProductHelper = rootDeviceEnvironment.getHelper<CompilerProductHelper>();
     this->heaplessModeEnabled = compilerProductHelper.isHeaplessModeEnabled(hwInfo);
     this->heaplessStateInitEnabled = compilerProductHelper.isHeaplessStateInitEnabled(heaplessModeEnabled);
-    this->evictionAllocations.reserve(2 * MemoryConstants::kiloByte);
 }
 
 CommandStreamReceiver::~CommandStreamReceiver() {
@@ -174,9 +173,7 @@ void CommandStreamReceiver::makeResident(GraphicsAllocation &gfxAllocation) {
     gfxAllocation.updateResidencyTaskCount(submissionTaskCount, osContext->getContextId());
 }
 
-void CommandStreamReceiver::processEviction() {
-    this->getEvictionAllocations().clear();
-}
+void CommandStreamReceiver::processEviction() {}
 
 void CommandStreamReceiver::makeNonResident(GraphicsAllocation &gfxAllocation) {
     if (gfxAllocation.isResident(osContext->getContextId())) {
@@ -261,6 +258,7 @@ void CommandStreamReceiver::ensureCommandBufferAllocation(LinearStream &commandS
 
     if (commandStream.getGraphicsAllocation() != nullptr) {
         getInternalAllocationStorage()->storeAllocation(std::unique_ptr<GraphicsAllocation>(commandStream.getGraphicsAllocation()), REUSABLE_ALLOCATION);
+        this->ucResourceRequiresTagUpdate = true;
     }
 
     commandStream.replaceBuffer(allocation->getUnderlyingBuffer(), allocationSize - additionalAllocationSize);
@@ -385,8 +383,11 @@ bool CommandStreamReceiver::isGpuHangDetected() const {
     if (debugManager.flags.DisableGpuHangDetection.get()) {
         return false;
     }
-
-    return this->osContext && this->getOSInterface() && this->getOSInterface()->getDriverModel() && this->getOSInterface()->getDriverModel()->isGpuHangDetected(*osContext);
+    auto isGpuHang = this->osContext && this->getOSInterface() && this->getOSInterface()->getDriverModel() && this->getOSInterface()->getDriverModel()->isGpuHangDetected(*osContext);
+    if (isGpuHang) {
+        this->getOSInterface()->getDriverModel()->getDeviceState();
+    }
+    return isGpuHang;
 }
 
 void CommandStreamReceiver::cleanupResources() {
@@ -546,6 +547,7 @@ void CommandStreamReceiver::setTagAllocation(GraphicsAllocation *allocation) {
     this->tagAddress = reinterpret_cast<TagAddressType *>(allocation->getUnderlyingBuffer());
     this->debugPauseStateAddress = reinterpret_cast<DebugPauseState *>(
         reinterpret_cast<uint8_t *>(allocation->getUnderlyingBuffer()) + TagAllocationLayout::debugPauseStateAddressOffset);
+    this->ucTagAddress = static_cast<TagAddressType *>(ptrOffset(allocation->getUnderlyingBuffer(), TagAllocationLayout::ucTagAddressOffset));
 }
 
 MultiGraphicsAllocation &CommandStreamReceiver::createMultiAllocationInSystemMemoryPool(AllocationType allocationType) {
@@ -630,9 +632,6 @@ ResidencyContainer &CommandStreamReceiver::getResidencyAllocations() {
     return this->residencyAllocations;
 }
 
-ResidencyContainer &CommandStreamReceiver::getEvictionAllocations() {
-    return this->evictionAllocations;
-}
 PrivateAllocsToReuseContainer &CommandStreamReceiver::getOwnedPrivateAllocations() {
     return this->ownedPrivateAllocations;
 }
@@ -742,8 +741,9 @@ IndirectHeap &CommandStreamReceiver::getIndirectHeap(IndirectHeap::Type heapType
     auto &heap = indirectHeap[heapType];
     GraphicsAllocation *heapMemory = nullptr;
 
-    if (heap)
+    if (heap) {
         heapMemory = heap->getGraphicsAllocation();
+    }
 
     if (heap && heap->getAvailableSpace() < minRequiredSize && heapMemory) {
         internalAllocationStorage->storeAllocation(std::unique_ptr<GraphicsAllocation>(heapMemory), REUSABLE_ALLOCATION);
@@ -808,8 +808,9 @@ void CommandStreamReceiver::releaseIndirectHeap(IndirectHeap::Type heapType) {
 
     if (heap) {
         auto heapMemory = heap->getGraphicsAllocation();
-        if (heapMemory != nullptr)
+        if (heapMemory != nullptr) {
             internalAllocationStorage->storeAllocation(std::unique_ptr<GraphicsAllocation>(heapMemory), REUSABLE_ALLOCATION);
+        }
         heap->replaceBuffer(nullptr, 0);
         heap->replaceGraphicsAllocation(nullptr);
     }
@@ -878,14 +879,18 @@ bool CommandStreamReceiver::initializeTagAllocation() {
     }
 
     this->setTagAllocation(tagAllocation);
+
     auto initValue = debugManager.flags.EnableNullHardware.get() ? static_cast<uint32_t>(-1) : initialHardwareTag;
     auto tagAddress = this->tagAddress;
+    auto ucTagAddress = this->ucTagAddress;
     auto completionFence = reinterpret_cast<TaskCountType *>(getCompletionAddress());
     UNRECOVERABLE_IF(!completionFence);
     uint32_t subDevices = static_cast<uint32_t>(this->deviceBitfield.count());
     for (uint32_t i = 0; i < subDevices; i++) {
         *tagAddress = initValue;
         tagAddress = ptrOffset(tagAddress, this->immWritePostSyncWriteOffset);
+        *ucTagAddress = initValue;
+        ucTagAddress = ptrOffset(ucTagAddress, this->immWritePostSyncWriteOffset);
         *completionFence = 0;
         completionFence = ptrOffset(completionFence, this->immWritePostSyncWriteOffset);
     }
@@ -1041,7 +1046,7 @@ uint32_t CommandStreamReceiver::getPreferredTagPoolSize() const {
 bool CommandStreamReceiver::expectMemory(const void *gfxAddress, const void *srcAddress,
                                          size_t length, uint32_t compareOperation) {
     auto isMemoryEqual = (memcmp(gfxAddress, srcAddress, length) == 0);
-    auto isEqualMemoryExpected = (compareOperation == AubMemDump::CmdServicesMemTraceMemoryCompare::CompareOperationValues::CompareEqual);
+    auto isEqualMemoryExpected = (compareOperation == aub_stream::CompareOperationValues::CompareEqual);
 
     return (isMemoryEqual == isEqualMemoryExpected);
 }
@@ -1208,6 +1213,7 @@ TaskCountType CompletionStamp::getTaskCountFromSubmissionStatusError(SubmissionS
 }
 uint64_t CommandStreamReceiver::getBarrierCountGpuAddress() const { return ptrOffset(this->tagAllocation->getGpuAddress(), TagAllocationLayout::barrierCountOffset); }
 uint64_t CommandStreamReceiver::getDebugPauseStateGPUAddress() const { return tagAllocation->getGpuAddress() + TagAllocationLayout::debugPauseStateAddressOffset; }
+uint64_t CommandStreamReceiver::getUcTagGPUAddress() const { return tagAllocation->getGpuAddress() + TagAllocationLayout::ucTagAddressOffset; }
 uint64_t CommandStreamReceiver::getCompletionAddress() const {
     uint64_t completionFenceAddress = castToUint64(const_cast<TagAddressType *>(tagAddress));
     if (completionFenceAddress == 0) {
@@ -1262,9 +1268,7 @@ void CommandStreamReceiver::ensurePrimaryCsrInitialized(Device &device) {
     csrToInitialize->initializeDeviceWithFirstSubmission(device);
 }
 
-void CommandStreamReceiver::addToEvictionContainer(GraphicsAllocation &gfxAllocation) {
-    this->getEvictionAllocations().push_back(&gfxAllocation);
-}
+void CommandStreamReceiver::addToEvictionContainer(GraphicsAllocation &gfxAllocation) {}
 
 std::function<void()> CommandStreamReceiver::debugConfirmationFunction = []() { std::cin.get(); };
 } // namespace NEO
