@@ -15,6 +15,7 @@
 #include "shared/source/helpers/cache_policy.h"
 #include "shared/source/helpers/common_types.h"
 #include "shared/source/helpers/completion_stamp.h"
+#include "shared/source/helpers/device_bitfield.h"
 #include "shared/source/helpers/kmd_notify_properties.h"
 #include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/helpers/options.h"
@@ -68,6 +69,7 @@ class ProductHelper;
 class ReleaseHelper;
 enum class WaitStatus;
 struct AubSubCaptureStatus;
+class SharedPoolAllocation;
 
 template <typename TSize, uint32_t packetCount>
 class TimestampPackets;
@@ -138,7 +140,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     MemoryManager *getMemoryManager() const;
 
     ResidencyContainer &getResidencyAllocations();
-    ResidencyContainer &getEvictionAllocations();
     PrivateAllocsToReuseContainer &getOwnedPrivateAllocations();
 
     virtual GmmPageTableMngr *createPageTableManager() { return nullptr; }
@@ -166,9 +167,11 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     TaskCountType getNextBarrierCount() { return this->barrierCount.fetch_add(1u); }
     TaskCountType peekBarrierCount() const { return this->barrierCount.load(); }
     volatile TagAddressType *getTagAddress() const { return tagAddress; }
+    volatile TagAddressType *getUcTagAddress() const { return ucTagAddress; }
     volatile TagAddressType *getBarrierCountTagAddress() const { return this->barrierCountTagAddress; }
     uint64_t getBarrierCountGpuAddress() const;
     uint64_t getDebugPauseStateGPUAddress() const;
+    uint64_t getUcTagGPUAddress() const;
 
     virtual bool waitForFlushStamp(FlushStamp &flushStampToWait) { return true; }
 
@@ -296,6 +299,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     MOCKABLE_VIRTUAL bool writeMemory(GraphicsAllocation &gfxAllocation) { return writeMemory(gfxAllocation, false, 0, 0); }
     virtual bool writeMemory(GraphicsAllocation &gfxAllocation, bool isChunkCopy, uint64_t gpuVaChunkOffset, size_t chunkSize) { return false; }
     virtual void writeMemoryAub(aub_stream::AllocationParams &allocationParams){};
+    virtual void writePooledMemory(SharedPoolAllocation &sharedPoolAllocation, bool initFullPageTables){};
     virtual void initializeEngine(){};
 
     virtual bool isMultiOsContextCapable() const = 0;
@@ -610,7 +614,6 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     std::unique_ptr<IndirectHeap> globalStatelessHeap;
 
     ResidencyContainer residencyAllocations;
-    ResidencyContainer evictionAllocations;
     PrivateAllocsToReuseContainer ownedPrivateAllocations;
 
     MutexType ownershipMutex;
@@ -628,6 +631,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     uint64_t totalMemoryUsed = 0u;
 
     volatile TagAddressType *tagAddress = nullptr;
+    volatile TagAddressType *ucTagAddress = nullptr;
     volatile TagAddressType *barrierCountTagAddress = nullptr;
     volatile DebugPauseState *debugPauseStateAddress = nullptr;
     SpinLock debugPauseStateLock;
@@ -695,6 +699,7 @@ class CommandStreamReceiver : NEO::NonCopyableAndNonMovableClass {
     bool gsbaStateDirty = true;
     bool bindingTableBaseAddressRequired = false;
     bool heapStorageRequiresRecyclingTag = false;
+    bool ucResourceRequiresTagUpdate = false;
     bool mediaVfeStateDirty = true;
     bool stateComputeModeDirty = true;
     bool btdCommandDirty = true;
