@@ -19,7 +19,6 @@
 
 #include <cstdint>
 #include <memory>
-#include <string>
 
 namespace AubMemDump {
 struct LrcaHelper;
@@ -65,7 +64,6 @@ class GfxCoreHelper {
     virtual bool isLocalMemoryEnabled(const HardwareInfo &hwInfo) const = 0;
     virtual bool is1MbAlignmentSupported(const HardwareInfo &hwInfo, bool isCompressionEnabled) const = 0;
     virtual bool isFenceAllocationRequired(const HardwareInfo &hwInfo, const ProductHelper &productHelper) const = 0;
-    virtual const AubMemDump::LrcaHelper &getCsTraits(aub_stream::EngineType engineType) const = 0;
     virtual bool hvAlign4Required() const = 0;
     virtual bool isBufferSizeSuitableForCompression(const size_t size) const = 0;
     virtual bool checkResourceCompatibility(GraphicsAllocation &graphicsAllocation) const = 0;
@@ -74,6 +72,7 @@ class GfxCoreHelper {
     static bool cacheFlushAfterWalkerSupported(const HardwareInfo &hwInfo);
     static uint32_t getHighestEnabledSlice(const HardwareInfo &hwInfo);
     static uint32_t getHighestEnabledDualSubSlice(const HardwareInfo &hwInfo);
+    static uint32_t getHighestEnabledSubSliceOnAnySlice(const HardwareInfo &hwInfo);
     virtual bool timestampPacketWriteSupported() const = 0;
     virtual bool isUpdateTaskCountFromWaitSupported() const = 0;
     virtual bool makeResidentBeforeLockNeeded(bool precondition) const = 0;
@@ -101,7 +100,6 @@ class GfxCoreHelper {
     virtual uint32_t calculateAvailableThreadCount(const HardwareInfo &hwInfo, uint32_t grfCount, const RootDeviceEnvironment &rootDeviceEnvironment) const = 0;
     virtual uint32_t calculateMaxWorkGroupSize(const KernelDescriptor &kernelDescriptor, uint32_t defaultMaxGroupSize, const RootDeviceEnvironment &rootDeviceEnvironment) const = 0;
     virtual uint32_t alignSlmSize(uint32_t slmSize) const = 0;
-    virtual uint32_t computeSlmValues(const HardwareInfo &hwInfo, uint32_t slmSize, ReleaseHelper *releaseHelper, bool isHeapless) const = 0;
 
     virtual bool isWaDisableRccRhwoOptimizationRequired() const = 0;
     virtual uint32_t getMinimalSIMDSize() const = 0;
@@ -134,7 +132,6 @@ class GfxCoreHelper {
     virtual uint32_t adjustMaxWorkGroupCount(uint32_t maxWorkGroupCount, const EngineGroupType engineGroupType,
                                              const RootDeviceEnvironment &rootDeviceEnvironment) const = 0;
     virtual uint32_t adjustMaxWorkGroupSize(const uint32_t grfCount, const uint32_t simd, const uint32_t defaultMaxGroupSize, const RootDeviceEnvironment &rootDeviceEnvironment) const = 0;
-    virtual size_t getMaxFillPatternSizeForCopyEngine() const = 0;
     virtual bool isCpuImageTransferPreferred(const HardwareInfo &hwInfo) const = 0;
     virtual aub_stream::MMIOList getExtraMmioList(const HardwareInfo &hwInfo, const GmmHelper &gmmHelper) const = 0;
     virtual bool isSubDeviceEngineSupported(const RootDeviceEnvironment &rootDeviceEnvironment, const DeviceBitfield &deviceBitfield, aub_stream::EngineType engineType) const = 0;
@@ -148,7 +145,6 @@ class GfxCoreHelper {
     virtual void applyAdditionalCompressionSettings(Gmm &gmm, bool isNotCompressed) const = 0;
     virtual bool isCompressionAppliedForImportedResource(Gmm &gmm) const = 0;
     virtual void applyRenderCompressionFlag(Gmm &gmm, uint32_t isCompressed) const = 0;
-    virtual bool unTypedDataPortCacheFlushRequired() const = 0;
     virtual bool isEngineTypeRemappingToHwSpecificRequired() const = 0;
 
     static uint32_t getSubDevicesCount(const HardwareInfo *pHwInfo);
@@ -205,7 +201,6 @@ class GfxCoreHelper {
                                                      bool requireInputWalkOrder,
                                                      uint32_t &requiredWalkOrder,
                                                      uint32_t simd) const = 0;
-    virtual uint32_t getMaxPtssIndex(const ProductHelper &productHelper) const = 0;
     virtual uint32_t getDefaultSshSize(const ProductHelper &productHelper) const = 0;
 
     virtual bool usmCompressionSupported(const NEO::HardwareInfo &hwInfo) const = 0;
@@ -265,8 +260,6 @@ class GfxCoreHelperHw : public GfxCoreHelper {
 
     uint32_t getRenderSurfaceStatePitch(void *renderSurfaceState, const ProductHelper &productHelper) const override;
 
-    const AubMemDump::LrcaHelper &getCsTraits(aub_stream::EngineType engineType) const override;
-
     size_t getMaxBarrierRegisterPerSlice() const override;
 
     size_t getPaddingForISAAllocation() const override;
@@ -348,16 +341,12 @@ class GfxCoreHelperHw : public GfxCoreHelper {
 
     uint32_t alignSlmSize(uint32_t slmSize) const override;
 
-    uint32_t computeSlmValues(const HardwareInfo &hwInfo, uint32_t slmSize, ReleaseHelper *releaseHelper, bool isHeapless) const override;
-
     static AuxTranslationMode getAuxTranslationMode(const HardwareInfo &hwInfo);
 
     bool isOffsetToSkipSetFFIDGPWARequired(const HardwareInfo &hwInfo, const ProductHelper &productHelper) const override;
 
     bool isFusedEuDispatchEnabled(const HardwareInfo &hwInfo, bool disableEUFusionForKernel) const override;
 
-    static bool isForceDefaultRCSEngineWARequired(const HardwareInfo &hwInfo);
-
     bool isWaDisableRccRhwoOptimizationRequired() const override;
 
     uint32_t getMinimalSIMDSize() const override;
@@ -401,7 +390,6 @@ class GfxCoreHelperHw : public GfxCoreHelper {
                                      const RootDeviceEnvironment &rootDeviceEnvironment) const override;
 
     uint32_t adjustMaxWorkGroupSize(const uint32_t grfCount, const uint32_t simd, const uint32_t defaultMaxGroupSize, const RootDeviceEnvironment &rootDeviceEnvironment) const override;
-    size_t getMaxFillPatternSizeForCopyEngine() const override;
 
     bool isCpuImageTransferPreferred(const HardwareInfo &hwInfo) const override;
 
@@ -426,7 +414,6 @@ class GfxCoreHelperHw : public GfxCoreHelper {
 
     void applyRenderCompressionFlag(Gmm &gmm, uint32_t isCompressed) const override;
 
-    bool unTypedDataPortCacheFlushRequired() const override;
     bool isEngineTypeRemappingToHwSpecificRequired() const override;
 
     bool isSipKernelAsHexadecimalArrayPreferred() const override;
@@ -479,7 +466,6 @@ class GfxCoreHelperHw : public GfxCoreHelper {
                                              bool requireInputWalkOrder,
                                              uint32_t &requiredWalkOrder,
                                              uint32_t simd) const override;
-    uint32_t getMaxPtssIndex(const ProductHelper &productHelper) const override;
     uint32_t getDefaultSshSize(const ProductHelper &productHelper) const override;
 
     bool usmCompressionSupported(const NEO::HardwareInfo &hwInfo) const override;
@@ -506,19 +492,6 @@ class GfxCoreHelperHw : public GfxCoreHelper {
     GfxCoreHelperHw() = default;
 };
 
-struct DwordBuilder {
-    static uint32_t build(uint32_t bitNumberToSet, bool masked, bool set = true, uint32_t initValue = 0) {
-        uint32_t dword = initValue;
-        if (set) {
-            dword |= (1 << bitNumberToSet);
-        }
-        if (masked) {
-            dword |= (1 << (bitNumberToSet + 16));
-        }
-        return dword;
-    };
-};
-
 template <typename GfxFamily>
 struct LriHelper {
     using MI_LOAD_REGISTER_IMM = typename GfxFamily::MI_LOAD_REGISTER_IMM;
@@ -540,7 +513,6 @@ struct MemorySynchronizationCommands {
 
     static void setPostSyncExtraProperties(PipeControlArgs &args);
 
-    static void addBarrierWa(LinearStream &commandStream, uint64_t gpuAddress, const RootDeviceEnvironment &rootDeviceEnvironment, NEO::PostSyncMode postSyncMode);
     static void setBarrierWa(void *&commandsBuffer, uint64_t gpuAddress, const RootDeviceEnvironment &rootDeviceEnvironment, NEO::PostSyncMode postSyncMode);
 
     static void setBarrierWaFlags(void *barrierCmd);
